@@ -1,6 +1,7 @@
 from PyQt5 import QtCore, QtGui, QtWidgets
 from PyQt5.Qt import *
 from PyQt5.uic import *
+from PyQt5.QtGui import *
 from PyQt5.QtCore import *
 from PyQt5.QtWidgets import *
 import sys
@@ -100,14 +101,15 @@ class Fast(QtWidgets.QMainWindow,Fast_link):
 class window(QtWidgets.QMainWindow,Ui_MainWindow):
     signal = pyqtSignal()
     fast_link = pyqtSignal()
-    version = '1.8.1'
+    version = '1.11'
+    log_name = 'log/'+time.strftime('%Y-%m-%d-%H-%H-%S')+'.log'
     def __init__(self):
 
 
 
 
         super(window,self).__init__()
-        with open('log/log.log', 'w') as f:
+        with open(self.log_name, 'w') as f:
             f.write('')
         self.log(f'[{time.ctime()}][main/Info] loading')
 
@@ -155,6 +157,29 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
         self.pushButton_7.clicked.connect(self.minecraft_build_client)
         self.pushButton_4.clicked.connect(self.set_block)
         self.pushButton_5.clicked.connect(self.set_blocks)
+        self.horizontalSlider.setValue(1000)
+
+        self.ti = QTimer()
+        self.ti.timeout.connect(self.fffff)
+        self.ti.start(0.01)
+
+        self.findpath()
+        self.pushButton_8.clicked.connect(self.findpath)
+
+
+
+
+
+    def findpath(self):
+        try:
+            model = QDirModel()
+            self.treeView.setModel(model)
+
+        except BaseException:
+            pass
+
+
+
     def minecraft_pi_init(self):
         self.textEdit.setText(self.textEdit.toPlainText()+'import mcpi.minecraft as Minecraft'+'\n')
     def minecraft_build_client(self):
@@ -219,7 +244,20 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
         self.pushButton_5.setText(dic['pushButton_5'])
         self.pushButton_6.setText(dic['pushButton_6'])
         self.pushButton_7.setText(dic['pushButton_7'])
-        self.horizontalSlider.setValue(1000)
+        self.pushButton_8.setText(dic['pushButton_8'])
+
+        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_7), dic['tab_win.tab_7'])
+        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_6), dic['tab_win.tab_6'])
+
+    def fffff(self):
+        r = self.verticalSlider_3.value()
+        g = self.verticalSlider_2.value()
+        b = self.verticalSlider.value()
+        self.label_16.setStyleSheet('color:rgb(85,85,255)')
+        self.label_16.setText(f'r:{r} g:{g} b:{b}\nr:{255-r} g:{255-g} b:{255-b}')
+        self.label_15.setStyleSheet(f'color:rgb({r},{g},{b})')
+        self.label_19.setStyleSheet(
+            f'color:rgb({255-r},{255-g},{255-b})')
 
     def fast(self):
         self.log(
@@ -239,7 +277,7 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
             self.textBrowser_2.setGeometry(QtCore.QRect(5, 1, 761, 221))
             self.textBrowser_2.setObjectName("textBrowser_2")
             self.textBrowser_2.setText(self.wdw)
-        with open('log/log.log','a') as f:
+        with open(self.log_name,'a') as f:
             f.write(text+'\n')
 
     def opencmd(self):
@@ -437,6 +475,7 @@ class Main:
         self.fast = Fast()
         self.window = window()
     def connect_windows(self):
+
         self.a.un.connect(self.a.run_script)
 
 
